# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2020.07.0]

### Changed
- Now uses Avro-RPC [Yep-107](https://yeps.yaq.fyi/107/)
- Use Flit for distribution
- Split topas4 into lightcon-topas4-motor and lightcon-topas4-shutter

## [2020.05.0]

### Added
- initial release

[Unreleased]: https://gitlab.com/yaq/yaqd-horiba/-/compare/v2020.05.0...master
[2020.05.0]: https://gitlab.com/yaq/yaqd-horiba/-/tags/v2020.05.0
